@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 import functools
 import re
@@ -22,16 +20,15 @@ from typing import Dict, Sequence, Tuple, Type, Union
 import pkg_resources
 
 import google.api_core.client_options as ClientOptions  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
 from google.cloud.vision_v1.types import image_annotator
-
 from .transports.base import ImageAnnotatorTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc_asyncio import ImageAnnotatorGrpcAsyncIOTransport
 from .client import ImageAnnotatorClient
@@ -53,42 +50,67 @@ class ImageAnnotatorAsyncClient:
     parse_product_path = staticmethod(ImageAnnotatorClient.parse_product_path)
     product_set_path = staticmethod(ImageAnnotatorClient.product_set_path)
     parse_product_set_path = staticmethod(ImageAnnotatorClient.parse_product_set_path)
-
     common_billing_account_path = staticmethod(
         ImageAnnotatorClient.common_billing_account_path
     )
     parse_common_billing_account_path = staticmethod(
         ImageAnnotatorClient.parse_common_billing_account_path
     )
-
     common_folder_path = staticmethod(ImageAnnotatorClient.common_folder_path)
     parse_common_folder_path = staticmethod(
         ImageAnnotatorClient.parse_common_folder_path
     )
-
     common_organization_path = staticmethod(
         ImageAnnotatorClient.common_organization_path
     )
     parse_common_organization_path = staticmethod(
         ImageAnnotatorClient.parse_common_organization_path
     )
-
     common_project_path = staticmethod(ImageAnnotatorClient.common_project_path)
     parse_common_project_path = staticmethod(
         ImageAnnotatorClient.parse_common_project_path
     )
-
     common_location_path = staticmethod(ImageAnnotatorClient.common_location_path)
     parse_common_location_path = staticmethod(
         ImageAnnotatorClient.parse_common_location_path
     )
 
-    from_service_account_file = ImageAnnotatorClient.from_service_account_file
+    @classmethod
+    def from_service_account_info(cls, info: dict, *args, **kwargs):
+        """Creates an instance of this client using the provided credentials
+            info.
+
+        Args:
+            info (dict): The service account private key info.
+            args: Additional arguments to pass to the constructor.
+            kwargs: Additional arguments to pass to the constructor.
+
+        Returns:
+            ImageAnnotatorAsyncClient: The constructed client.
+        """
+        return ImageAnnotatorClient.from_service_account_info.__func__(ImageAnnotatorAsyncClient, info, *args, **kwargs)  # type: ignore
+
+    @classmethod
+    def from_service_account_file(cls, filename: str, *args, **kwargs):
+        """Creates an instance of this client using the provided credentials
+            file.
+
+        Args:
+            filename (str): The path to the service account private key json
+                file.
+            args: Additional arguments to pass to the constructor.
+            kwargs: Additional arguments to pass to the constructor.
+
+        Returns:
+            ImageAnnotatorAsyncClient: The constructed client.
+        """
+        return ImageAnnotatorClient.from_service_account_file.__func__(ImageAnnotatorAsyncClient, filename, *args, **kwargs)  # type: ignore
+
     from_service_account_json = from_service_account_file
 
     @property
     def transport(self) -> ImageAnnotatorTransport:
-        """Return the transport used by the client instance.
+        """Returns the transport used by the client instance.
 
         Returns:
             ImageAnnotatorTransport: The transport used by the client instance.
@@ -102,12 +124,12 @@ class ImageAnnotatorAsyncClient:
     def __init__(
         self,
         *,
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         transport: Union[str, ImageAnnotatorTransport] = "grpc_asyncio",
         client_options: ClientOptions = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
-        """Instantiate the image annotator client.
+        """Instantiates the image annotator client.
 
         Args:
             credentials (Optional[google.auth.credentials.Credentials]): The
@@ -139,7 +161,6 @@ class ImageAnnotatorAsyncClient:
             google.auth.exceptions.MutualTlsChannelError: If mutual TLS transport
                 creation failed for any reason.
         """
-
         self._client = ImageAnnotatorClient(
             credentials=credentials,
             transport=transport,
@@ -160,16 +181,16 @@ class ImageAnnotatorAsyncClient:
         images.
 
         Args:
-            request (:class:`~.image_annotator.BatchAnnotateImagesRequest`):
+            request (:class:`google.cloud.vision_v1.types.BatchAnnotateImagesRequest`):
                 The request object. Multiple image annotation requests
                 are batched into a single service call.
-            requests (:class:`Sequence[~.image_annotator.AnnotateImageRequest]`):
+            requests (:class:`Sequence[google.cloud.vision_v1.types.AnnotateImageRequest]`):
                 Required. Individual image annotation
                 requests for this batch.
+
                 This corresponds to the ``requests`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -177,7 +198,7 @@ class ImageAnnotatorAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.image_annotator.BatchAnnotateImagesResponse:
+            google.cloud.vision_v1.types.BatchAnnotateImagesResponse:
                 Response to a batch image annotation
                 request.
 
@@ -196,7 +217,6 @@ class ImageAnnotatorAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if requests:
             request.requests.extend(requests)
 
@@ -209,8 +229,10 @@ class ImageAnnotatorAsyncClient:
                 maximum=60.0,
                 multiplier=1.3,
                 predicate=retries.if_exception_type(
-                    exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                    core_exceptions.DeadlineExceeded,
+                    core_exceptions.ServiceUnavailable,
                 ),
+                deadline=600.0,
             ),
             default_timeout=600.0,
             client_info=DEFAULT_CLIENT_INFO,
@@ -241,18 +263,18 @@ class ImageAnnotatorAsyncClient:
         extracted.
 
         Args:
-            request (:class:`~.image_annotator.BatchAnnotateFilesRequest`):
+            request (:class:`google.cloud.vision_v1.types.BatchAnnotateFilesRequest`):
                 The request object. A list of requests to annotate files
                 using the BatchAnnotateFiles API.
-            requests (:class:`Sequence[~.image_annotator.AnnotateFileRequest]`):
+            requests (:class:`Sequence[google.cloud.vision_v1.types.AnnotateFileRequest]`):
                 Required. The list of file annotation
                 requests. Right now we support only one
                 AnnotateFileRequest in
                 BatchAnnotateFilesRequest.
+
                 This corresponds to the ``requests`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -260,7 +282,7 @@ class ImageAnnotatorAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.image_annotator.BatchAnnotateFilesResponse:
+            google.cloud.vision_v1.types.BatchAnnotateFilesResponse:
                 A list of file annotation responses.
         """
         # Create or coerce a protobuf request object.
@@ -277,7 +299,6 @@ class ImageAnnotatorAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if requests:
             request.requests.extend(requests)
 
@@ -290,8 +311,10 @@ class ImageAnnotatorAsyncClient:
                 maximum=60.0,
                 multiplier=1.3,
                 predicate=retries.if_exception_type(
-                    exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                    core_exceptions.DeadlineExceeded,
+                    core_exceptions.ServiceUnavailable,
                 ),
+                deadline=600.0,
             ),
             default_timeout=600.0,
             client_info=DEFAULT_CLIENT_INFO,
@@ -327,22 +350,23 @@ class ImageAnnotatorAsyncClient:
         BatchAnnotateImagesResponse proto.
 
         Args:
-            request (:class:`~.image_annotator.AsyncBatchAnnotateImagesRequest`):
+            request (:class:`google.cloud.vision_v1.types.AsyncBatchAnnotateImagesRequest`):
                 The request object. Request for async image annotation
                 for a list of images.
-            requests (:class:`Sequence[~.image_annotator.AnnotateImageRequest]`):
+            requests (:class:`Sequence[google.cloud.vision_v1.types.AnnotateImageRequest]`):
                 Required. Individual image annotation
                 requests for this batch.
+
                 This corresponds to the ``requests`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            output_config (:class:`~.image_annotator.OutputConfig`):
+            output_config (:class:`google.cloud.vision_v1.types.OutputConfig`):
                 Required. The desired output location
                 and metadata (e.g. format).
+
                 This corresponds to the ``output_config`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -350,11 +374,11 @@ class ImageAnnotatorAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.operation_async.AsyncOperation:
+            google.api_core.operation_async.AsyncOperation:
                 An object representing a long-running operation.
 
                 The result type for the operation will be
-                :class:``~.image_annotator.AsyncBatchAnnotateImagesResponse``:
+                :class:`google.cloud.vision_v1.types.AsyncBatchAnnotateImagesResponse`
                 Response to an async batch image annotation request.
 
         """
@@ -372,10 +396,8 @@ class ImageAnnotatorAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if output_config is not None:
             request.output_config = output_config
-
         if requests:
             request.requests.extend(requests)
 
@@ -388,8 +410,10 @@ class ImageAnnotatorAsyncClient:
                 maximum=60.0,
                 multiplier=1.3,
                 predicate=retries.if_exception_type(
-                    exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                    core_exceptions.DeadlineExceeded,
+                    core_exceptions.ServiceUnavailable,
                 ),
+                deadline=600.0,
             ),
             default_timeout=600.0,
             client_info=DEFAULT_CLIENT_INFO,
@@ -427,16 +451,16 @@ class ImageAnnotatorAsyncClient:
         ``AsyncBatchAnnotateFilesResponse`` (results).
 
         Args:
-            request (:class:`~.image_annotator.AsyncBatchAnnotateFilesRequest`):
+            request (:class:`google.cloud.vision_v1.types.AsyncBatchAnnotateFilesRequest`):
                 The request object. Multiple async file annotation
                 requests are batched into a single service call.
-            requests (:class:`Sequence[~.image_annotator.AsyncAnnotateFileRequest]`):
+            requests (:class:`Sequence[google.cloud.vision_v1.types.AsyncAnnotateFileRequest]`):
                 Required. Individual async file
                 annotation requests for this batch.
+
                 This corresponds to the ``requests`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -444,11 +468,11 @@ class ImageAnnotatorAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.operation_async.AsyncOperation:
+            google.api_core.operation_async.AsyncOperation:
                 An object representing a long-running operation.
 
                 The result type for the operation will be
-                :class:``~.image_annotator.AsyncBatchAnnotateFilesResponse``:
+                :class:`google.cloud.vision_v1.types.AsyncBatchAnnotateFilesResponse`
                 Response to an async batch file annotation request.
 
         """
@@ -466,7 +490,6 @@ class ImageAnnotatorAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if requests:
             request.requests.extend(requests)
 
@@ -479,8 +502,10 @@ class ImageAnnotatorAsyncClient:
                 maximum=60.0,
                 multiplier=1.3,
                 predicate=retries.if_exception_type(
-                    exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                    core_exceptions.DeadlineExceeded,
+                    core_exceptions.ServiceUnavailable,
                 ),
+                deadline=600.0,
             ),
             default_timeout=600.0,
             client_info=DEFAULT_CLIENT_INFO,
@@ -500,6 +525,12 @@ class ImageAnnotatorAsyncClient:
         # Done; return the response.
         return response
 
+    async def __aenter__(self):
+        return self
+
+    async def __aexit__(self, exc_type, exc, tb):
+        await self.transport.close()
+
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
