@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,19 +13,18 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 from distutils import util
 import os
 import re
-from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
@@ -35,7 +33,6 @@ from google.oauth2 import service_account  # type: ignore
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
 from google.cloud.vision_v1.types import image_annotator
-
 from .transports.base import ImageAnnotatorTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc import ImageAnnotatorGrpcTransport
 from .transports.grpc_asyncio import ImageAnnotatorGrpcAsyncIOTransport
@@ -56,7 +53,7 @@ class ImageAnnotatorClientMeta(type):
     _transport_registry["grpc_asyncio"] = ImageAnnotatorGrpcAsyncIOTransport
 
     def get_transport_class(cls, label: str = None,) -> Type[ImageAnnotatorTransport]:
-        """Return an appropriate transport class.
+        """Returns an appropriate transport class.
 
         Args:
             label: The name of the desired transport. If none is
@@ -83,7 +80,8 @@ class ImageAnnotatorClient(metaclass=ImageAnnotatorClientMeta):
 
     @staticmethod
     def _get_default_mtls_endpoint(api_endpoint):
-        """Convert api endpoint to mTLS endpoint.
+        """Converts api endpoint to mTLS endpoint.
+
         Convert "*.sandbox.googleapis.com" and "*.googleapis.com" to
         "*.mtls.sandbox.googleapis.com" and "*.mtls.googleapis.com" respectively.
         Args:
@@ -115,10 +113,27 @@ class ImageAnnotatorClient(metaclass=ImageAnnotatorClientMeta):
         DEFAULT_ENDPOINT
     )
 
+    @classmethod
+    def from_service_account_info(cls, info: dict, *args, **kwargs):
+        """Creates an instance of this client using the provided credentials
+            info.
+
+        Args:
+            info (dict): The service account private key info.
+            args: Additional arguments to pass to the constructor.
+            kwargs: Additional arguments to pass to the constructor.
+
+        Returns:
+            ImageAnnotatorClient: The constructed client.
+        """
+        credentials = service_account.Credentials.from_service_account_info(info)
+        kwargs["credentials"] = credentials
+        return cls(*args, **kwargs)
+
     @classmethod
     def from_service_account_file(cls, filename: str, *args, **kwargs):
         """Creates an instance of this client using the provided credentials
-        file.
+            file.
 
         Args:
             filename (str): The path to the service account private key json
@@ -127,7 +142,7 @@ class ImageAnnotatorClient(metaclass=ImageAnnotatorClientMeta):
             kwargs: Additional arguments to pass to the constructor.
 
         Returns:
-            {@api.name}: The constructed client.
+            ImageAnnotatorClient: The constructed client.
         """
         credentials = service_account.Credentials.from_service_account_file(filename)
         kwargs["credentials"] = credentials
@@ -137,23 +152,24 @@ class ImageAnnotatorClient(metaclass=ImageAnnotatorClientMeta):
 
     @property
     def transport(self) -> ImageAnnotatorTransport:
-        """Return the transport used by the client instance.
+        """Returns the transport used by the client instance.
 
         Returns:
-            ImageAnnotatorTransport: The transport used by the client instance.
+            ImageAnnotatorTransport: The transport used by the client
+                instance.
         """
         return self._transport
 
     @staticmethod
     def product_path(project: str, location: str, product: str,) -> str:
-        """Return a fully-qualified product string."""
+        """Returns a fully-qualified product string."""
         return "projects/{project}/locations/{location}/products/{product}".format(
             project=project, location=location, product=product,
         )
 
     @staticmethod
     def parse_product_path(path: str) -> Dict[str, str]:
-        """Parse a product path into its component segments."""
+        """Parses a product path into its component segments."""
         m = re.match(
             r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)/products/(?P<product>.+?)$",
             path,
@@ -162,14 +178,14 @@ class ImageAnnotatorClient(metaclass=ImageAnnotatorClientMeta):
 
     @staticmethod
     def product_set_path(project: str, location: str, product_set: str,) -> str:
-        """Return a fully-qualified product_set string."""
+        """Returns a fully-qualified product_set string."""
         return "projects/{project}/locations/{location}/productSets/{product_set}".format(
             project=project, location=location, product_set=product_set,
         )
 
     @staticmethod
     def parse_product_set_path(path: str) -> Dict[str, str]:
-        """Parse a product_set path into its component segments."""
+        """Parses a product_set path into its component segments."""
         m = re.match(
             r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)/productSets/(?P<product_set>.+?)$",
             path,
@@ -178,7 +194,7 @@ class ImageAnnotatorClient(metaclass=ImageAnnotatorClientMeta):
 
     @staticmethod
     def common_billing_account_path(billing_account: str,) -> str:
-        """Return a fully-qualified billing_account string."""
+        """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
         )
@@ -191,7 +207,7 @@ class ImageAnnotatorClient(metaclass=ImageAnnotatorClientMeta):
 
     @staticmethod
     def common_folder_path(folder: str,) -> str:
-        """Return a fully-qualified folder string."""
+        """Returns a fully-qualified folder string."""
         return "folders/{folder}".format(folder=folder,)
 
     @staticmethod
@@ -202,7 +218,7 @@ class ImageAnnotatorClient(metaclass=ImageAnnotatorClientMeta):
 
     @staticmethod
     def common_organization_path(organization: str,) -> str:
-        """Return a fully-qualified organization string."""
+        """Returns a fully-qualified organization string."""
         return "organizations/{organization}".format(organization=organization,)
 
     @staticmethod
@@ -213,7 +229,7 @@ class ImageAnnotatorClient(metaclass=ImageAnnotatorClientMeta):
 
     @staticmethod
     def common_project_path(project: str,) -> str:
-        """Return a fully-qualified project string."""
+        """Returns a fully-qualified project string."""
         return "projects/{project}".format(project=project,)
 
     @staticmethod
@@ -224,7 +240,7 @@ class ImageAnnotatorClient(metaclass=ImageAnnotatorClientMeta):
 
     @staticmethod
     def common_location_path(project: str, location: str,) -> str:
-        """Return a fully-qualified location string."""
+        """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
             project=project, location=location,
         )
@@ -238,12 +254,12 @@ class ImageAnnotatorClient(metaclass=ImageAnnotatorClientMeta):
     def __init__(
         self,
         *,
-        credentials: Optional[credentials.Credentials] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, ImageAnnotatorTransport, None] = None,
         client_options: Optional[client_options_lib.ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
-        """Instantiate the image annotator client.
+        """Instantiates the image annotator client.
 
         Args:
             credentials (Optional[google.auth.credentials.Credentials]): The
@@ -251,10 +267,10 @@ class ImageAnnotatorClient(metaclass=ImageAnnotatorClientMeta):
                 credentials identify the application to the service; if none
                 are specified, the client will attempt to ascertain the
                 credentials from the environment.
-            transport (Union[str, ~.ImageAnnotatorTransport]): The
+            transport (Union[str, ImageAnnotatorTransport]): The
                 transport to use. If set to None, a transport is chosen
                 automatically.
-            client_options (client_options_lib.ClientOptions): Custom options for the
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
@@ -290,21 +306,18 @@ class ImageAnnotatorClient(metaclass=ImageAnnotatorClientMeta):
             util.strtobool(os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false"))
         )
 
-        ssl_credentials = None
+        client_cert_source_func = None
         is_mtls = False
         if use_client_cert:
             if client_options.client_cert_source:
-                import grpc  # type: ignore
-
-                cert, key = client_options.client_cert_source()
-                ssl_credentials = grpc.ssl_channel_credentials(
-                    certificate_chain=cert, private_key=key
-                )
                 is_mtls = True
+                client_cert_source_func = client_options.client_cert_source
             else:
-                creds = SslCredentials()
-                is_mtls = creds.is_mtls
-                ssl_credentials = creds.ssl_credentials if is_mtls else None
+                is_mtls = mtls.has_default_client_cert_source()
+                if is_mtls:
+                    client_cert_source_func = mtls.default_client_cert_source()
+                else:
+                    client_cert_source_func = None
 
         # Figure out which api endpoint to use.
         if client_options.api_endpoint is not None:
@@ -316,12 +329,14 @@ class ImageAnnotatorClient(metaclass=ImageAnnotatorClientMeta):
             elif use_mtls_env == "always":
                 api_endpoint = self.DEFAULT_MTLS_ENDPOINT
             elif use_mtls_env == "auto":
-                api_endpoint = (
-                    self.DEFAULT_MTLS_ENDPOINT if is_mtls else self.DEFAULT_ENDPOINT
-                )
+                if is_mtls:
+                    api_endpoint = self.DEFAULT_MTLS_ENDPOINT
+                else:
+                    api_endpoint = self.DEFAULT_ENDPOINT
             else:
                 raise MutualTLSChannelError(
-                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted values: never, auto, always"
+                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted "
+                    "values: never, auto, always"
                 )
 
         # Save or instantiate the transport.
@@ -336,8 +351,8 @@ class ImageAnnotatorClient(metaclass=ImageAnnotatorClientMeta):
                 )
             if client_options.scopes:
                 raise ValueError(
-                    "When providing a transport instance, "
-                    "provide its scopes directly."
+                    "When providing a transport instance, provide its scopes "
+                    "directly."
                 )
             self._transport = transport
         else:
@@ -347,14 +362,15 @@ class ImageAnnotatorClient(metaclass=ImageAnnotatorClientMeta):
                 credentials_file=client_options.credentials_file,
                 host=api_endpoint,
                 scopes=client_options.scopes,
-                ssl_channel_credentials=ssl_credentials,
+                client_cert_source_for_mtls=client_cert_source_func,
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
+                always_use_jwt_access=True,
             )
 
     def batch_annotate_images(
         self,
-        request: image_annotator.BatchAnnotateImagesRequest = None,
+        request: Union[image_annotator.BatchAnnotateImagesRequest, dict] = None,
         *,
         requests: Sequence[image_annotator.AnnotateImageRequest] = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -365,16 +381,16 @@ class ImageAnnotatorClient(metaclass=ImageAnnotatorClientMeta):
         images.
 
         Args:
-            request (:class:`~.image_annotator.BatchAnnotateImagesRequest`):
+            request (Union[google.cloud.vision_v1.types.BatchAnnotateImagesRequest, dict]):
                 The request object. Multiple image annotation requests
                 are batched into a single service call.
-            requests (:class:`Sequence[~.image_annotator.AnnotateImageRequest]`):
+            requests (Sequence[google.cloud.vision_v1.types.AnnotateImageRequest]):
                 Required. Individual image annotation
                 requests for this batch.
+
                 This corresponds to the ``requests`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -382,7 +398,7 @@ class ImageAnnotatorClient(metaclass=ImageAnnotatorClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.image_annotator.BatchAnnotateImagesResponse:
+            google.cloud.vision_v1.types.BatchAnnotateImagesResponse:
                 Response to a batch image annotation
                 request.
 
@@ -406,12 +422,10 @@ class ImageAnnotatorClient(metaclass=ImageAnnotatorClientMeta):
             if requests is not None:
                 for i in range(len(requests)):
                     requests[i] = image_annotator.AnnotateImageRequest(requests[i])
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
-            if requests:
-                request.requests.extend(requests)
+            if requests is not None:
+                request.requests = requests
 
         # Wrap the RPC method; this adds retry and timeout information,
         # and friendly error handling.
@@ -425,7 +439,7 @@ class ImageAnnotatorClient(metaclass=ImageAnnotatorClientMeta):
 
     def batch_annotate_files(
         self,
-        request: image_annotator.BatchAnnotateFilesRequest = None,
+        request: Union[image_annotator.BatchAnnotateFilesRequest, dict] = None,
         *,
         requests: Sequence[image_annotator.AnnotateFileRequest] = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -442,18 +456,18 @@ class ImageAnnotatorClient(metaclass=ImageAnnotatorClientMeta):
         extracted.
 
         Args:
-            request (:class:`~.image_annotator.BatchAnnotateFilesRequest`):
+            request (Union[google.cloud.vision_v1.types.BatchAnnotateFilesRequest, dict]):
                 The request object. A list of requests to annotate files
                 using the BatchAnnotateFiles API.
-            requests (:class:`Sequence[~.image_annotator.AnnotateFileRequest]`):
+            requests (Sequence[google.cloud.vision_v1.types.AnnotateFileRequest]):
                 Required. The list of file annotation
                 requests. Right now we support only one
                 AnnotateFileRequest in
                 BatchAnnotateFilesRequest.
+
                 This corresponds to the ``requests`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -461,7 +475,7 @@ class ImageAnnotatorClient(metaclass=ImageAnnotatorClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.image_annotator.BatchAnnotateFilesResponse:
+            google.cloud.vision_v1.types.BatchAnnotateFilesResponse:
                 A list of file annotation responses.
         """
         # Create or coerce a protobuf request object.
@@ -483,12 +497,10 @@ class ImageAnnotatorClient(metaclass=ImageAnnotatorClientMeta):
             if requests is not None:
                 for i in range(len(requests)):
                     requests[i] = image_annotator.AnnotateFileRequest(requests[i])
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
-            if requests:
-                request.requests.extend(requests)
+            if requests is not None:
+                request.requests = requests
 
         # Wrap the RPC method; this adds retry and timeout information,
         # and friendly error handling.
@@ -502,7 +514,7 @@ class ImageAnnotatorClient(metaclass=ImageAnnotatorClientMeta):
 
     def async_batch_annotate_images(
         self,
-        request: image_annotator.AsyncBatchAnnotateImagesRequest = None,
+        request: Union[image_annotator.AsyncBatchAnnotateImagesRequest, dict] = None,
         *,
         requests: Sequence[image_annotator.AnnotateImageRequest] = None,
         output_config: image_annotator.OutputConfig = None,
@@ -524,22 +536,23 @@ class ImageAnnotatorClient(metaclass=ImageAnnotatorClientMeta):
         BatchAnnotateImagesResponse proto.
 
         Args:
-            request (:class:`~.image_annotator.AsyncBatchAnnotateImagesRequest`):
+            request (Union[google.cloud.vision_v1.types.AsyncBatchAnnotateImagesRequest, dict]):
                 The request object. Request for async image annotation
                 for a list of images.
-            requests (:class:`Sequence[~.image_annotator.AnnotateImageRequest]`):
+            requests (Sequence[google.cloud.vision_v1.types.AnnotateImageRequest]):
                 Required. Individual image annotation
                 requests for this batch.
+
                 This corresponds to the ``requests`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            output_config (:class:`~.image_annotator.OutputConfig`):
+            output_config (google.cloud.vision_v1.types.OutputConfig):
                 Required. The desired output location
                 and metadata (e.g. format).
+
                 This corresponds to the ``output_config`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -547,11 +560,11 @@ class ImageAnnotatorClient(metaclass=ImageAnnotatorClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.operation.Operation:
+            google.api_core.operation.Operation:
                 An object representing a long-running operation.
 
                 The result type for the operation will be
-                :class:``~.image_annotator.AsyncBatchAnnotateImagesResponse``:
+                :class:`google.cloud.vision_v1.types.AsyncBatchAnnotateImagesResponse`
                 Response to an async batch image annotation request.
 
         """
@@ -574,16 +587,13 @@ class ImageAnnotatorClient(metaclass=ImageAnnotatorClientMeta):
             if requests is not None:
                 for i in range(len(requests)):
                     requests[i] = image_annotator.AnnotateImageRequest(requests[i])
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
+            if requests is not None:
+                request.requests = requests
             if output_config is not None:
                 request.output_config = output_config
 
-            if requests:
-                request.requests.extend(requests)
-
         # Wrap the RPC method; this adds retry and timeout information,
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[
@@ -606,7 +616,7 @@ class ImageAnnotatorClient(metaclass=ImageAnnotatorClientMeta):
 
     def async_batch_annotate_files(
         self,
-        request: image_annotator.AsyncBatchAnnotateFilesRequest = None,
+        request: Union[image_annotator.AsyncBatchAnnotateFilesRequest, dict] = None,
         *,
         requests: Sequence[image_annotator.AsyncAnnotateFileRequest] = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -622,16 +632,16 @@ class ImageAnnotatorClient(metaclass=ImageAnnotatorClientMeta):
         ``AsyncBatchAnnotateFilesResponse`` (results).
 
         Args:
-            request (:class:`~.image_annotator.AsyncBatchAnnotateFilesRequest`):
+            request (Union[google.cloud.vision_v1.types.AsyncBatchAnnotateFilesRequest, dict]):
                 The request object. Multiple async file annotation
                 requests are batched into a single service call.
-            requests (:class:`Sequence[~.image_annotator.AsyncAnnotateFileRequest]`):
+            requests (Sequence[google.cloud.vision_v1.types.AsyncAnnotateFileRequest]):
                 Required. Individual async file
                 annotation requests for this batch.
+
                 This corresponds to the ``requests`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -639,11 +649,11 @@ class ImageAnnotatorClient(metaclass=ImageAnnotatorClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.operation.Operation:
+            google.api_core.operation.Operation:
                 An object representing a long-running operation.
 
                 The result type for the operation will be
-                :class:``~.image_annotator.AsyncBatchAnnotateFilesResponse``:
+                :class:`google.cloud.vision_v1.types.AsyncBatchAnnotateFilesResponse`
                 Response to an async batch file annotation request.
 
         """
@@ -666,12 +676,10 @@ class ImageAnnotatorClient(metaclass=ImageAnnotatorClientMeta):
             if requests is not None:
                 for i in range(len(requests)):
                     requests[i] = image_annotator.AsyncAnnotateFileRequest(requests[i])
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
-            if requests:
-                request.requests.extend(requests)
+            if requests is not None:
+                request.requests = requests
 
         # Wrap the RPC method; this adds retry and timeout information,
         # and friendly error handling.
@@ -693,6 +701,19 @@ class ImageAnnotatorClient(metaclass=ImageAnnotatorClientMeta):
         # Done; return the response.
         return response
 
+    def __enter__(self):
+        return self
+
+    def __exit__(self, type, value, traceback):
+        """Releases underlying transport's resources.
+
+        .. warning::
+            ONLY use as a context manager if the transport is NOT shared
+            with other clients! Exiting the with block will CLOSE the transport
+            and may cause errors in other clients!
+        """
+        self.transport.close()
+
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
