@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,24 +13,22 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import warnings
-from typing import Awaitable, Callable, Dict, Optional, Sequence, Tuple
+from typing import Awaitable, Callable, Dict, Optional, Sequence, Tuple, Union
 
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import grpc_helpers_async  # type: ignore
 from google.api_core import operations_v1  # type: ignore
-from google import auth  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
+import packaging.version
 
 import grpc  # type: ignore
 from grpc.experimental import aio  # type: ignore
 
 from google.cloud.vision_v1.types import product_search_service
-from google.longrunning import operations_pb2 as operations  # type: ignore
-from google.protobuf import empty_pb2 as empty  # type: ignore
-
+from google.longrunning import operations_pb2  # type: ignore
+from google.protobuf import empty_pb2  # type: ignore
 from .base import ProductSearchTransport, DEFAULT_CLIENT_INFO
 from .grpc import ProductSearchGrpcTransport
 
@@ -73,7 +70,7 @@ class ProductSearchGrpcAsyncIOTransport(ProductSearchTransport):
     def create_channel(
         cls,
         host: str = "vision.googleapis.com",
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         credentials_file: Optional[str] = None,
         scopes: Optional[Sequence[str]] = None,
         quota_project_id: Optional[str] = None,
@@ -81,7 +78,7 @@ class ProductSearchGrpcAsyncIOTransport(ProductSearchTransport):
     ) -> aio.Channel:
         """Create and return a gRPC AsyncIO channel object.
         Args:
-            address (Optional[str]): The host for the channel to use.
+            host (Optional[str]): The host for the channel to use.
             credentials (Optional[~.Credentials]): The
                 authorization credentials to attach to requests. These
                 credentials identify this application to the service. If
@@ -100,13 +97,15 @@ class ProductSearchGrpcAsyncIOTransport(ProductSearchTransport):
         Returns:
             aio.Channel: A gRPC AsyncIO channel object.
         """
-        scopes = scopes or cls.AUTH_SCOPES
+
         return grpc_helpers_async.create_channel(
             host,
             credentials=credentials,
             credentials_file=credentials_file,
-            scopes=scopes,
             quota_project_id=quota_project_id,
+            default_scopes=cls.AUTH_SCOPES,
+            scopes=scopes,
+            default_host=cls.DEFAULT_HOST,
             **kwargs,
         )
 
@@ -114,20 +113,23 @@ class ProductSearchGrpcAsyncIOTransport(ProductSearchTransport):
         self,
         *,
         host: str = "vision.googleapis.com",
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         credentials_file: Optional[str] = None,
         scopes: Optional[Sequence[str]] = None,
         channel: aio.Channel = None,
         api_mtls_endpoint: str = None,
         client_cert_source: Callable[[], Tuple[bytes, bytes]] = None,
         ssl_channel_credentials: grpc.ChannelCredentials = None,
+        client_cert_source_for_mtls: Callable[[], Tuple[bytes, bytes]] = None,
         quota_project_id=None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
+        always_use_jwt_access: Optional[bool] = False,
     ) -> None:
         """Instantiate the transport.
 
         Args:
-            host (Optional[str]): The hostname to connect to.
+            host (Optional[str]):
+                 The hostname to connect to.
             credentials (Optional[google.auth.credentials.Credentials]): The
                 authorization credentials to attach to requests. These
                 credentials identify the application to the service; if none
@@ -145,20 +147,26 @@ class ProductSearchGrpcAsyncIOTransport(ProductSearchTransport):
             api_mtls_endpoint (Optional[str]): Deprecated. The mutual TLS endpoint.
                 If provided, it overrides the ``host`` argument and tries to create
                 a mutual TLS channel with client SSL credentials from
-                ``client_cert_source`` or applicatin default SSL credentials.
+                ``client_cert_source`` or application default SSL credentials.
             client_cert_source (Optional[Callable[[], Tuple[bytes, bytes]]]):
                 Deprecated. A callback to provide client SSL certificate bytes and
                 private key bytes, both in PEM format. It is ignored if
                 ``api_mtls_endpoint`` is None.
             ssl_channel_credentials (grpc.ChannelCredentials): SSL credentials
-                for grpc channel. It is ignored if ``channel`` is provided.
+                for the grpc channel. It is ignored if ``channel`` is provided.
+            client_cert_source_for_mtls (Optional[Callable[[], Tuple[bytes, bytes]]]):
+                A callback to provide client certificate bytes and private key bytes,
+                both in PEM format. It is used to configure a mutual TLS channel. It is
+                ignored if ``channel`` or ``ssl_channel_credentials`` is provided.
             quota_project_id (Optional[str]): An optional project to use for billing
                 and quota.
-            client_info (google.api_core.gapic_v1.client_info.ClientInfo):	
-                The client info used to send a user-agent string along with	
-                API requests. If ``None``, then default info will be used.	
-                Generally, you only need to set this if you're developing	
+            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
+                The client info used to send a user-agent string along with
+                API requests. If ``None``, then default info will be used.
+                Generally, you only need to set this if you're developing
                 your own client library.
+            always_use_jwt_access (Optional[bool]): Whether self signed JWT should
+                be used for service account credentials.
 
         Raises:
             google.auth.exceptions.MutualTlsChannelError: If mutual TLS transport
@@ -166,91 +174,70 @@ class ProductSearchGrpcAsyncIOTransport(ProductSearchTransport):
           google.api_core.exceptions.DuplicateCredentialArgs: If both ``credentials``
               and ``credentials_file`` are passed.
         """
+        self._grpc_channel = None
         self._ssl_channel_credentials = ssl_channel_credentials
+        self._stubs: Dict[str, Callable] = {}
+        self._operations_client = None
+
+        if api_mtls_endpoint:
+            warnings.warn("api_mtls_endpoint is deprecated", DeprecationWarning)
+        if client_cert_source:
+            warnings.warn("client_cert_source is deprecated", DeprecationWarning)
 
         if channel:
-            # Sanity check: Ensure that channel and credentials are not both
-            # provided.
+            # Ignore credentials if a channel was passed.
             credentials = False
-
             # If a channel was explicitly provided, set it.
             self._grpc_channel = channel
             self._ssl_channel_credentials = None
-        elif api_mtls_endpoint:
-            warnings.warn(
-                "api_mtls_endpoint and client_cert_source are deprecated",
-                DeprecationWarning,
-            )
-
-            host = (
-                api_mtls_endpoint
-                if ":" in api_mtls_endpoint
-                else api_mtls_endpoint + ":443"
-            )
-
-            if credentials is None:
-                credentials, _ = auth.default(
-                    scopes=self.AUTH_SCOPES, quota_project_id=quota_project_id
-                )
-
-            # Create SSL credentials with client_cert_source or application
-            # default SSL credentials.
-            if client_cert_source:
-                cert, key = client_cert_source()
-                ssl_credentials = grpc.ssl_channel_credentials(
-                    certificate_chain=cert, private_key=key
-                )
-            else:
-                ssl_credentials = SslCredentials().ssl_credentials
-
-            # create a new channel. The provided one is ignored.
-            self._grpc_channel = type(self).create_channel(
-                host,
-                credentials=credentials,
-                credentials_file=credentials_file,
-                ssl_credentials=ssl_credentials,
-                scopes=scopes or self.AUTH_SCOPES,
-                quota_project_id=quota_project_id,
-                options=[
-                    ("grpc.max_send_message_length", -1),
-                    ("grpc.max_receive_message_length", -1),
-                ],
-            )
-            self._ssl_channel_credentials = ssl_credentials
         else:
-            host = host if ":" in host else host + ":443"
+            if api_mtls_endpoint:
+                host = api_mtls_endpoint
 
-            if credentials is None:
-                credentials, _ = auth.default(
-                    scopes=self.AUTH_SCOPES, quota_project_id=quota_project_id
-                )
+                # Create SSL credentials with client_cert_source or application
+                # default SSL credentials.
+                if client_cert_source:
+                    cert, key = client_cert_source()
+                    self._ssl_channel_credentials = grpc.ssl_channel_credentials(
+                        certificate_chain=cert, private_key=key
+                    )
+                else:
+                    self._ssl_channel_credentials = SslCredentials().ssl_credentials
 
-            # create a new channel. The provided one is ignored.
-            self._grpc_channel = type(self).create_channel(
-                host,
-                credentials=credentials,
-                credentials_file=credentials_file,
-                ssl_credentials=ssl_channel_credentials,
-                scopes=scopes or self.AUTH_SCOPES,
-                quota_project_id=quota_project_id,
-                options=[
-                    ("grpc.max_send_message_length", -1),
-                    ("grpc.max_receive_message_length", -1),
-                ],
-            )
+            else:
+                if client_cert_source_for_mtls and not ssl_channel_credentials:
+                    cert, key = client_cert_source_for_mtls()
+                    self._ssl_channel_credentials = grpc.ssl_channel_credentials(
+                        certificate_chain=cert, private_key=key
+                    )
 
-        # Run the base constructor.
+        # The base transport sets the host, credentials and scopes
         super().__init__(
             host=host,
             credentials=credentials,
             credentials_file=credentials_file,
-            scopes=scopes or self.AUTH_SCOPES,
+            scopes=scopes,
             quota_project_id=quota_project_id,
             client_info=client_info,
+            always_use_jwt_access=always_use_jwt_access,
         )
 
-        self._stubs = {}
-        self._operations_client = None
+        if not self._grpc_channel:
+            self._grpc_channel = type(self).create_channel(
+                self._host,
+                credentials=self._credentials,
+                credentials_file=credentials_file,
+                scopes=self._scopes,
+                ssl_credentials=self._ssl_channel_credentials,
+                quota_project_id=quota_project_id,
+                options=[
+                    ("grpc.max_send_message_length", -1),
+                    ("grpc.max_receive_message_length", -1),
+                ],
+            )
+
+        # Wrap messages. This must be done after self._grpc_channel exists
+        self._prep_wrapped_messages(client_info)
 
     @property
     def grpc_channel(self) -> aio.Channel:
@@ -420,7 +407,7 @@ class ProductSearchGrpcAsyncIOTransport(ProductSearchTransport):
     def delete_product_set(
         self,
     ) -> Callable[
-        [product_search_service.DeleteProductSetRequest], Awaitable[empty.Empty]
+        [product_search_service.DeleteProductSetRequest], Awaitable[empty_pb2.Empty]
     ]:
         r"""Return a callable for the delete product set method over gRPC.
 
@@ -443,7 +430,7 @@ class ProductSearchGrpcAsyncIOTransport(ProductSearchTransport):
             self._stubs["delete_product_set"] = self.grpc_channel.unary_unary(
                 "/google.cloud.vision.v1.ProductSearch/DeleteProductSet",
                 request_serializer=product_search_service.DeleteProductSetRequest.serialize,
-                response_deserializer=empty.Empty.FromString,
+                response_deserializer=empty_pb2.Empty.FromString,
             )
         return self._stubs["delete_product_set"]
 
@@ -600,7 +587,7 @@ class ProductSearchGrpcAsyncIOTransport(ProductSearchTransport):
     def delete_product(
         self,
     ) -> Callable[
-        [product_search_service.DeleteProductRequest], Awaitable[empty.Empty]
+        [product_search_service.DeleteProductRequest], Awaitable[empty_pb2.Empty]
     ]:
         r"""Return a callable for the delete product method over gRPC.
 
@@ -625,7 +612,7 @@ class ProductSearchGrpcAsyncIOTransport(ProductSearchTransport):
             self._stubs["delete_product"] = self.grpc_channel.unary_unary(
                 "/google.cloud.vision.v1.ProductSearch/DeleteProduct",
                 request_serializer=product_search_service.DeleteProductRequest.serialize,
-                response_deserializer=empty.Empty.FromString,
+                response_deserializer=empty_pb2.Empty.FromString,
             )
         return self._stubs["delete_product"]
 
@@ -683,7 +670,7 @@ class ProductSearchGrpcAsyncIOTransport(ProductSearchTransport):
     def delete_reference_image(
         self,
     ) -> Callable[
-        [product_search_service.DeleteReferenceImageRequest], Awaitable[empty.Empty]
+        [product_search_service.DeleteReferenceImageRequest], Awaitable[empty_pb2.Empty]
     ]:
         r"""Return a callable for the delete reference image method over gRPC.
 
@@ -709,7 +696,7 @@ class ProductSearchGrpcAsyncIOTransport(ProductSearchTransport):
             self._stubs["delete_reference_image"] = self.grpc_channel.unary_unary(
                 "/google.cloud.vision.v1.ProductSearch/DeleteReferenceImage",
                 request_serializer=product_search_service.DeleteReferenceImageRequest.serialize,
-                response_deserializer=empty.Empty.FromString,
+                response_deserializer=empty_pb2.Empty.FromString,
             )
         return self._stubs["delete_reference_image"]
 
@@ -785,7 +772,8 @@ class ProductSearchGrpcAsyncIOTransport(ProductSearchTransport):
     def add_product_to_product_set(
         self,
     ) -> Callable[
-        [product_search_service.AddProductToProductSetRequest], Awaitable[empty.Empty]
+        [product_search_service.AddProductToProductSetRequest],
+        Awaitable[empty_pb2.Empty],
     ]:
         r"""Return a callable for the add product to product set method over gRPC.
 
@@ -813,7 +801,7 @@ class ProductSearchGrpcAsyncIOTransport(ProductSearchTransport):
             self._stubs["add_product_to_product_set"] = self.grpc_channel.unary_unary(
                 "/google.cloud.vision.v1.ProductSearch/AddProductToProductSet",
                 request_serializer=product_search_service.AddProductToProductSetRequest.serialize,
-                response_deserializer=empty.Empty.FromString,
+                response_deserializer=empty_pb2.Empty.FromString,
             )
         return self._stubs["add_product_to_product_set"]
 
@@ -822,7 +810,7 @@ class ProductSearchGrpcAsyncIOTransport(ProductSearchTransport):
         self,
     ) -> Callable[
         [product_search_service.RemoveProductFromProductSetRequest],
-        Awaitable[empty.Empty],
+        Awaitable[empty_pb2.Empty],
     ]:
         r"""Return a callable for the remove product from product
         set method over gRPC.
@@ -845,7 +833,7 @@ class ProductSearchGrpcAsyncIOTransport(ProductSearchTransport):
             ] = self.grpc_channel.unary_unary(
                 "/google.cloud.vision.v1.ProductSearch/RemoveProductFromProductSet",
                 request_serializer=product_search_service.RemoveProductFromProductSetRequest.serialize,
-                response_deserializer=empty.Empty.FromString,
+                response_deserializer=empty_pb2.Empty.FromString,
             )
         return self._stubs["remove_product_from_product_set"]
 
@@ -890,7 +878,7 @@ class ProductSearchGrpcAsyncIOTransport(ProductSearchTransport):
         self,
     ) -> Callable[
         [product_search_service.ImportProductSetsRequest],
-        Awaitable[operations.Operation],
+        Awaitable[operations_pb2.Operation],
     ]:
         r"""Return a callable for the import product sets method over gRPC.
 
@@ -921,7 +909,7 @@ class ProductSearchGrpcAsyncIOTransport(ProductSearchTransport):
             self._stubs["import_product_sets"] = self.grpc_channel.unary_unary(
                 "/google.cloud.vision.v1.ProductSearch/ImportProductSets",
                 request_serializer=product_search_service.ImportProductSetsRequest.serialize,
-                response_deserializer=operations.Operation.FromString,
+                response_deserializer=operations_pb2.Operation.FromString,
             )
         return self._stubs["import_product_sets"]
 
@@ -929,7 +917,8 @@ class ProductSearchGrpcAsyncIOTransport(ProductSearchTransport):
     def purge_products(
         self,
     ) -> Callable[
-        [product_search_service.PurgeProductsRequest], Awaitable[operations.Operation]
+        [product_search_service.PurgeProductsRequest],
+        Awaitable[operations_pb2.Operation],
     ]:
         r"""Return a callable for the purge products method over gRPC.
 
@@ -975,9 +964,12 @@ class ProductSearchGrpcAsyncIOTransport(ProductSearchTransport):
             self._stubs["purge_products"] = self.grpc_channel.unary_unary(
                 "/google.cloud.vision.v1.ProductSearch/PurgeProducts",
                 request_serializer=product_search_service.PurgeProductsRequest.serialize,
-                response_deserializer=operations.Operation.FromString,
+                response_deserializer=operations_pb2.Operation.FromString,
             )
         return self._stubs["purge_products"]
 
+    def close(self):
+        return self.grpc_channel.close()
+
 
 __all__ = ("ProductSearchGrpcAsyncIOTransport",)
