@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,8 +13,16 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
-from typing import Any, AsyncIterable, Awaitable, Callable, Iterable, Sequence, Tuple
+from typing import (
+    Any,
+    AsyncIterator,
+    Awaitable,
+    Callable,
+    Sequence,
+    Tuple,
+    Optional,
+    Iterator,
+)
 
 from google.cloud.vision_v1p3beta1.types import product_search_service
 
@@ -24,7 +31,7 @@ class ListProductSetsPager:
     """A pager for iterating through ``list_product_sets`` requests.
 
     This class thinly wraps an initial
-    :class:`~.product_search_service.ListProductSetsResponse` object, and
+    :class:`google.cloud.vision_v1p3beta1.types.ListProductSetsResponse` object, and
     provides an ``__iter__`` method to iterate through its
     ``product_sets`` field.
 
@@ -33,7 +40,7 @@ class ListProductSetsPager:
     through the ``product_sets`` field on the
     corresponding responses.
 
-    All the usual :class:`~.product_search_service.ListProductSetsResponse`
+    All the usual :class:`google.cloud.vision_v1p3beta1.types.ListProductSetsResponse`
     attributes are available on the pager. If multiple requests are made, only
     the most recent response is retained, and thus used for attribute lookup.
     """
@@ -51,9 +58,9 @@ class ListProductSetsPager:
         Args:
             method (Callable): The method that was originally called, and
                 which instantiated this pager.
-            request (:class:`~.product_search_service.ListProductSetsRequest`):
+            request (google.cloud.vision_v1p3beta1.types.ListProductSetsRequest):
                 The initial request object.
-            response (:class:`~.product_search_service.ListProductSetsResponse`):
+            response (google.cloud.vision_v1p3beta1.types.ListProductSetsResponse):
                 The initial response object.
             metadata (Sequence[Tuple[str, str]]): Strings which should be
                 sent along with the request as metadata.
@@ -67,14 +74,14 @@ class ListProductSetsPager:
         return getattr(self._response, name)
 
     @property
-    def pages(self) -> Iterable[product_search_service.ListProductSetsResponse]:
+    def pages(self) -> Iterator[product_search_service.ListProductSetsResponse]:
         yield self._response
         while self._response.next_page_token:
             self._request.page_token = self._response.next_page_token
             self._response = self._method(self._request, metadata=self._metadata)
             yield self._response
 
-    def __iter__(self) -> Iterable[product_search_service.ProductSet]:
+    def __iter__(self) -> Iterator[product_search_service.ProductSet]:
         for page in self.pages:
             yield from page.product_sets
 
@@ -86,7 +93,7 @@ class ListProductSetsAsyncPager:
     """A pager for iterating through ``list_product_sets`` requests.
 
     This class thinly wraps an initial
-    :class:`~.product_search_service.ListProductSetsResponse` object, and
+    :class:`google.cloud.vision_v1p3beta1.types.ListProductSetsResponse` object, and
     provides an ``__aiter__`` method to iterate through its
     ``product_sets`` field.
 
@@ -95,7 +102,7 @@ class ListProductSetsAsyncPager:
     through the ``product_sets`` field on the
     corresponding responses.
 
-    All the usual :class:`~.product_search_service.ListProductSetsResponse`
+    All the usual :class:`google.cloud.vision_v1p3beta1.types.ListProductSetsResponse`
     attributes are available on the pager. If multiple requests are made, only
     the most recent response is retained, and thus used for attribute lookup.
     """
@@ -110,14 +117,14 @@ class ListProductSetsAsyncPager:
         *,
         metadata: Sequence[Tuple[str, str]] = ()
     ):
-        """Instantiate the pager.
+        """Instantiates the pager.
 
         Args:
             method (Callable): The method that was originally called, and
                 which instantiated this pager.
-            request (:class:`~.product_search_service.ListProductSetsRequest`):
+            request (google.cloud.vision_v1p3beta1.types.ListProductSetsRequest):
                 The initial request object.
-            response (:class:`~.product_search_service.ListProductSetsResponse`):
+            response (google.cloud.vision_v1p3beta1.types.ListProductSetsResponse):
                 The initial response object.
             metadata (Sequence[Tuple[str, str]]): Strings which should be
                 sent along with the request as metadata.
@@ -133,14 +140,14 @@ class ListProductSetsAsyncPager:
     @property
     async def pages(
         self,
-    ) -> AsyncIterable[product_search_service.ListProductSetsResponse]:
+    ) -> AsyncIterator[product_search_service.ListProductSetsResponse]:
         yield self._response
         while self._response.next_page_token:
             self._request.page_token = self._response.next_page_token
             self._response = await self._method(self._request, metadata=self._metadata)
             yield self._response
 
-    def __aiter__(self) -> AsyncIterable[product_search_service.ProductSet]:
+    def __aiter__(self) -> AsyncIterator[product_search_service.ProductSet]:
         async def async_generator():
             async for page in self.pages:
                 for response in page.product_sets:
@@ -156,7 +163,7 @@ class ListProductsPager:
     """A pager for iterating through ``list_products`` requests.
 
     This class thinly wraps an initial
-    :class:`~.product_search_service.ListProductsResponse` object, and
+    :class:`google.cloud.vision_v1p3beta1.types.ListProductsResponse` object, and
     provides an ``__iter__`` method to iterate through its
     ``products`` field.
 
@@ -165,7 +172,7 @@ class ListProductsPager:
     through the ``products`` field on the
     corresponding responses.
 
-    All the usual :class:`~.product_search_service.ListProductsResponse`
+    All the usual :class:`google.cloud.vision_v1p3beta1.types.ListProductsResponse`
     attributes are available on the pager. If multiple requests are made, only
     the most recent response is retained, and thus used for attribute lookup.
     """
@@ -183,9 +190,9 @@ class ListProductsPager:
         Args:
             method (Callable): The method that was originally called, and
                 which instantiated this pager.
-            request (:class:`~.product_search_service.ListProductsRequest`):
+            request (google.cloud.vision_v1p3beta1.types.ListProductsRequest):
                 The initial request object.
-            response (:class:`~.product_search_service.ListProductsResponse`):
+            response (google.cloud.vision_v1p3beta1.types.ListProductsResponse):
                 The initial response object.
             metadata (Sequence[Tuple[str, str]]): Strings which should be
                 sent along with the request as metadata.
@@ -199,14 +206,14 @@ class ListProductsPager:
         return getattr(self._response, name)
 
     @property
-    def pages(self) -> Iterable[product_search_service.ListProductsResponse]:
+    def pages(self) -> Iterator[product_search_service.ListProductsResponse]:
         yield self._response
         while self._response.next_page_token:
             self._request.page_token = self._response.next_page_token
             self._response = self._method(self._request, metadata=self._metadata)
             yield self._response
 
-    def __iter__(self) -> Iterable[product_search_service.Product]:
+    def __iter__(self) -> Iterator[product_search_service.Product]:
         for page in self.pages:
             yield from page.products
 
@@ -218,7 +225,7 @@ class ListProductsAsyncPager:
     """A pager for iterating through ``list_products`` requests.
 
     This class thinly wraps an initial
-    :class:`~.product_search_service.ListProductsResponse` object, and
+    :class:`google.cloud.vision_v1p3beta1.types.ListProductsResponse` object, and
     provides an ``__aiter__`` method to iterate through its
     ``products`` field.
 
@@ -227,7 +234,7 @@ class ListProductsAsyncPager:
     through the ``products`` field on the
     corresponding responses.
 
-    All the usual :class:`~.product_search_service.ListProductsResponse`
+    All the usual :class:`google.cloud.vision_v1p3beta1.types.ListProductsResponse`
     attributes are available on the pager. If multiple requests are made, only
     the most recent response is retained, and thus used for attribute lookup.
     """
@@ -240,14 +247,14 @@ class ListProductsAsyncPager:
         *,
         metadata: Sequence[Tuple[str, str]] = ()
     ):
-        """Instantiate the pager.
+        """Instantiates the pager.
 
         Args:
             method (Callable): The method that was originally called, and
                 which instantiated this pager.
-            request (:class:`~.product_search_service.ListProductsRequest`):
+            request (google.cloud.vision_v1p3beta1.types.ListProductsRequest):
                 The initial request object.
-            response (:class:`~.product_search_service.ListProductsResponse`):
+            response (google.cloud.vision_v1p3beta1.types.ListProductsResponse):
                 The initial response object.
             metadata (Sequence[Tuple[str, str]]): Strings which should be
                 sent along with the request as metadata.
@@ -261,14 +268,14 @@ class ListProductsAsyncPager:
         return getattr(self._response, name)
 
     @property
-    async def pages(self) -> AsyncIterable[product_search_service.ListProductsResponse]:
+    async def pages(self) -> AsyncIterator[product_search_service.ListProductsResponse]:
         yield self._response
         while self._response.next_page_token:
             self._request.page_token = self._response.next_page_token
             self._response = await self._method(self._request, metadata=self._metadata)
             yield self._response
 
-    def __aiter__(self) -> AsyncIterable[product_search_service.Product]:
+    def __aiter__(self) -> AsyncIterator[product_search_service.Product]:
         async def async_generator():
             async for page in self.pages:
                 for response in page.products:
@@ -284,7 +291,7 @@ class ListReferenceImagesPager:
     """A pager for iterating through ``list_reference_images`` requests.
 
     This class thinly wraps an initial
-    :class:`~.product_search_service.ListReferenceImagesResponse` object, and
+    :class:`google.cloud.vision_v1p3beta1.types.ListReferenceImagesResponse` object, and
     provides an ``__iter__`` method to iterate through its
     ``reference_images`` field.
 
@@ -293,7 +300,7 @@ class ListReferenceImagesPager:
     through the ``reference_images`` field on the
     corresponding responses.
 
-    All the usual :class:`~.product_search_service.ListReferenceImagesResponse`
+    All the usual :class:`google.cloud.vision_v1p3beta1.types.ListReferenceImagesResponse`
     attributes are available on the pager. If multiple requests are made, only
     the most recent response is retained, and thus used for attribute lookup.
     """
@@ -311,9 +318,9 @@ class ListReferenceImagesPager:
         Args:
             method (Callable): The method that was originally called, and
                 which instantiated this pager.
-            request (:class:`~.product_search_service.ListReferenceImagesRequest`):
+            request (google.cloud.vision_v1p3beta1.types.ListReferenceImagesRequest):
                 The initial request object.
-            response (:class:`~.product_search_service.ListReferenceImagesResponse`):
+            response (google.cloud.vision_v1p3beta1.types.ListReferenceImagesResponse):
                 The initial response object.
             metadata (Sequence[Tuple[str, str]]): Strings which should be
                 sent along with the request as metadata.
@@ -327,14 +334,14 @@ class ListReferenceImagesPager:
         return getattr(self._response, name)
 
     @property
-    def pages(self) -> Iterable[product_search_service.ListReferenceImagesResponse]:
+    def pages(self) -> Iterator[product_search_service.ListReferenceImagesResponse]:
         yield self._response
         while self._response.next_page_token:
             self._request.page_token = self._response.next_page_token
             self._response = self._method(self._request, metadata=self._metadata)
             yield self._response
 
-    def __iter__(self) -> Iterable[product_search_service.ReferenceImage]:
+    def __iter__(self) -> Iterator[product_search_service.ReferenceImage]:
         for page in self.pages:
             yield from page.reference_images
 
@@ -346,7 +353,7 @@ class ListReferenceImagesAsyncPager:
     """A pager for iterating through ``list_reference_images`` requests.
 
     This class thinly wraps an initial
-    :class:`~.product_search_service.ListReferenceImagesResponse` object, and
+    :class:`google.cloud.vision_v1p3beta1.types.ListReferenceImagesResponse` object, and
     provides an ``__aiter__`` method to iterate through its
     ``reference_images`` field.
 
@@ -355,7 +362,7 @@ class ListReferenceImagesAsyncPager:
     through the ``reference_images`` field on the
     corresponding responses.
 
-    All the usual :class:`~.product_search_service.ListReferenceImagesResponse`
+    All the usual :class:`google.cloud.vision_v1p3beta1.types.ListReferenceImagesResponse`
     attributes are available on the pager. If multiple requests are made, only
     the most recent response is retained, and thus used for attribute lookup.
     """
@@ -370,14 +377,14 @@ class ListReferenceImagesAsyncPager:
         *,
         metadata: Sequence[Tuple[str, str]] = ()
     ):
-        """Instantiate the pager.
+        """Instantiates the pager.
 
         Args:
             method (Callable): The method that was originally called, and
                 which instantiated this pager.
-            request (:class:`~.product_search_service.ListReferenceImagesRequest`):
+            request (google.cloud.vision_v1p3beta1.types.ListReferenceImagesRequest):
                 The initial request object.
-            response (:class:`~.product_search_service.ListReferenceImagesResponse`):
+            response (google.cloud.vision_v1p3beta1.types.ListReferenceImagesResponse):
                 The initial response object.
             metadata (Sequence[Tuple[str, str]]): Strings which should be
                 sent along with the request as metadata.
@@ -393,14 +400,14 @@ class ListReferenceImagesAsyncPager:
     @property
     async def pages(
         self,
-    ) -> AsyncIterable[product_search_service.ListReferenceImagesResponse]:
+    ) -> AsyncIterator[product_search_service.ListReferenceImagesResponse]:
         yield self._response
         while self._response.next_page_token:
             self._request.page_token = self._response.next_page_token
             self._response = await self._method(self._request, metadata=self._metadata)
             yield self._response
 
-    def __aiter__(self) -> AsyncIterable[product_search_service.ReferenceImage]:
+    def __aiter__(self) -> AsyncIterator[product_search_service.ReferenceImage]:
         async def async_generator():
             async for page in self.pages:
                 for response in page.reference_images:
@@ -416,7 +423,7 @@ class ListProductsInProductSetPager:
     """A pager for iterating through ``list_products_in_product_set`` requests.
 
     This class thinly wraps an initial
-    :class:`~.product_search_service.ListProductsInProductSetResponse` object, and
+    :class:`google.cloud.vision_v1p3beta1.types.ListProductsInProductSetResponse` object, and
     provides an ``__iter__`` method to iterate through its
     ``products`` field.
 
@@ -425,7 +432,7 @@ class ListProductsInProductSetPager:
     through the ``products`` field on the
     corresponding responses.
 
-    All the usual :class:`~.product_search_service.ListProductsInProductSetResponse`
+    All the usual :class:`google.cloud.vision_v1p3beta1.types.ListProductsInProductSetResponse`
     attributes are available on the pager. If multiple requests are made, only
     the most recent response is retained, and thus used for attribute lookup.
     """
@@ -443,9 +450,9 @@ class ListProductsInProductSetPager:
         Args:
             method (Callable): The method that was originally called, and
                 which instantiated this pager.
-            request (:class:`~.product_search_service.ListProductsInProductSetRequest`):
+            request (google.cloud.vision_v1p3beta1.types.ListProductsInProductSetRequest):
                 The initial request object.
-            response (:class:`~.product_search_service.ListProductsInProductSetResponse`):
+            response (google.cloud.vision_v1p3beta1.types.ListProductsInProductSetResponse):
                 The initial response object.
             metadata (Sequence[Tuple[str, str]]): Strings which should be
                 sent along with the request as metadata.
@@ -461,14 +468,14 @@ class ListProductsInProductSetPager:
     @property
     def pages(
         self,
-    ) -> Iterable[product_search_service.ListProductsInProductSetResponse]:
+    ) -> Iterator[product_search_service.ListProductsInProductSetResponse]:
         yield self._response
         while self._response.next_page_token:
             self._request.page_token = self._response.next_page_token
             self._response = self._method(self._request, metadata=self._metadata)
             yield self._response
 
-    def __iter__(self) -> Iterable[product_search_service.Product]:
+    def __iter__(self) -> Iterator[product_search_service.Product]:
         for page in self.pages:
             yield from page.products
 
@@ -480,7 +487,7 @@ class ListProductsInProductSetAsyncPager:
     """A pager for iterating through ``list_products_in_product_set`` requests.
 
     This class thinly wraps an initial
-    :class:`~.product_search_service.ListProductsInProductSetResponse` object, and
+    :class:`google.cloud.vision_v1p3beta1.types.ListProductsInProductSetResponse` object, and
     provides an ``__aiter__`` method to iterate through its
     ``products`` field.
 
@@ -489,7 +496,7 @@ class ListProductsInProductSetAsyncPager:
     through the ``products`` field on the
     corresponding responses.
 
-    All the usual :class:`~.product_search_service.ListProductsInProductSetResponse`
+    All the usual :class:`google.cloud.vision_v1p3beta1.types.ListProductsInProductSetResponse`
     attributes are available on the pager. If multiple requests are made, only
     the most recent response is retained, and thus used for attribute lookup.
     """
@@ -504,14 +511,14 @@ class ListProductsInProductSetAsyncPager:
         *,
         metadata: Sequence[Tuple[str, str]] = ()
     ):
-        """Instantiate the pager.
+        """Instantiates the pager.
 
         Args:
             method (Callable): The method that was originally called, and
                 which instantiated this pager.
-            request (:class:`~.product_search_service.ListProductsInProductSetRequest`):
+            request (google.cloud.vision_v1p3beta1.types.ListProductsInProductSetRequest):
                 The initial request object.
-            response (:class:`~.product_search_service.ListProductsInProductSetResponse`):
+            response (google.cloud.vision_v1p3beta1.types.ListProductsInProductSetResponse):
                 The initial response object.
             metadata (Sequence[Tuple[str, str]]): Strings which should be
                 sent along with the request as metadata.
@@ -527,14 +534,14 @@ class ListProductsInProductSetAsyncPager:
     @property
     async def pages(
         self,
-    ) -> AsyncIterable[product_search_service.ListProductsInProductSetResponse]:
+    ) -> AsyncIterator[product_search_service.ListProductsInProductSetResponse]:
         yield self._response
         while self._response.next_page_token:
             self._request.page_token = self._response.next_page_token
             self._response = await self._method(self._request, metadata=self._metadata)
             yield self._response
 
-    def __aiter__(self) -> AsyncIterable[product_search_service.Product]:
+    def __aiter__(self) -> AsyncIterator[product_search_service.Product]:
         async def async_generator():
             async for page in self.pages:
                 for response in page.products:
