@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,14 +13,12 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import proto  # type: ignore
 
-
 from google.cloud.vision_v1p3beta1.types import geometry
-from google.protobuf import field_mask_pb2 as field_mask  # type: ignore
-from google.protobuf import timestamp_pb2 as timestamp  # type: ignore
-from google.rpc import status_pb2 as status  # type: ignore
+from google.protobuf import field_mask_pb2  # type: ignore
+from google.protobuf import timestamp_pb2  # type: ignore
+from google.rpc import status_pb2  # type: ignore
 
 
 __protobuf__ = proto.module(
@@ -85,7 +82,7 @@ class Product(proto.Message):
             "toys-v2". The legacy categories "homegoods",
             "apparel", and "toys" are still supported, but
             these should not be used for new products.
-        product_labels (Sequence[~.product_search_service.Product.KeyValue]):
+        product_labels (Sequence[google.cloud.vision_v1p3beta1.types.Product.KeyValue]):
             Key-value pairs that can be attached to a product. At query
             time, constraints can be specified based on the
             product_labels.
@@ -111,18 +108,13 @@ class Product(proto.Message):
                 bytes.
         """
 
-        key = proto.Field(proto.STRING, number=1)
-
-        value = proto.Field(proto.STRING, number=2)
-
-    name = proto.Field(proto.STRING, number=1)
-
-    display_name = proto.Field(proto.STRING, number=2)
-
-    description = proto.Field(proto.STRING, number=3)
-
-    product_category = proto.Field(proto.STRING, number=4)
+        key = proto.Field(proto.STRING, number=1,)
+        value = proto.Field(proto.STRING, number=2,)
 
+    name = proto.Field(proto.STRING, number=1,)
+    display_name = proto.Field(proto.STRING, number=2,)
+    description = proto.Field(proto.STRING, number=3,)
+    product_category = proto.Field(proto.STRING, number=4,)
     product_labels = proto.RepeatedField(proto.MESSAGE, number=5, message=KeyValue,)
 
 
@@ -143,7 +135,7 @@ class ProductSet(proto.Message):
             The user-provided name for this ProductSet.
             Must not be empty. Must be at most 4096
             characters long.
-        index_time (~.timestamp.Timestamp):
+        index_time (google.protobuf.timestamp_pb2.Timestamp):
             Output only. The time at which this
             ProductSet was last indexed. Query results will
             reflect all updates before this time. If this
@@ -152,7 +144,7 @@ class ProductSet(proto.Message):
 
             This field is ignored when creating a
             ProductSet.
-        index_error (~.status.Status):
+        index_error (google.rpc.status_pb2.Status):
             Output only. If there was an error with
             indexing the product set, the field is
             populated.
@@ -160,13 +152,10 @@ class ProductSet(proto.Message):
             ProductSet.
     """
 
-    name = proto.Field(proto.STRING, number=1)
-
-    display_name = proto.Field(proto.STRING, number=2)
-
-    index_time = proto.Field(proto.MESSAGE, number=3, message=timestamp.Timestamp,)
-
-    index_error = proto.Field(proto.MESSAGE, number=4, message=status.Status,)
+    name = proto.Field(proto.STRING, number=1,)
+    display_name = proto.Field(proto.STRING, number=2,)
+    index_time = proto.Field(proto.MESSAGE, number=3, message=timestamp_pb2.Timestamp,)
+    index_error = proto.Field(proto.MESSAGE, number=4, message=status_pb2.Status,)
 
 
 class ReferenceImage(proto.Message):
@@ -187,7 +176,7 @@ class ReferenceImage(proto.Message):
             image.
 
             The URI must start with ``gs://``.
-        bounding_polys (Sequence[~.geometry.BoundingPoly]):
+        bounding_polys (Sequence[google.cloud.vision_v1p3beta1.types.BoundingPoly]):
             Optional. Bounding polygons around the areas
             of interest in the reference image. If this
             field is empty, the system will try to detect
@@ -200,10 +189,8 @@ class ReferenceImage(proto.Message):
             1:4 or less (i.e. 1:3 is ok; 1:5 is not).
     """
 
-    name = proto.Field(proto.STRING, number=1)
-
-    uri = proto.Field(proto.STRING, number=2)
-
+    name = proto.Field(proto.STRING, number=1,)
+    uri = proto.Field(proto.STRING, number=2,)
     bounding_polys = proto.RepeatedField(
         proto.MESSAGE, number=3, message=geometry.BoundingPoly,
     )
@@ -218,7 +205,7 @@ class CreateProductRequest(proto.Message):
             created.
 
             Format is ``projects/PROJECT_ID/locations/LOC_ID``.
-        product (~.product_search_service.Product):
+        product (google.cloud.vision_v1p3beta1.types.Product):
             Required. The product to create.
         product_id (str):
             A user-supplied resource id for this Product. If set, the
@@ -228,11 +215,9 @@ class CreateProductRequest(proto.Message):
             cannot contain the character ``/``.
     """
 
-    parent = proto.Field(proto.STRING, number=1)
-
+    parent = proto.Field(proto.STRING, number=1,)
     product = proto.Field(proto.MESSAGE, number=2, message="Product",)
-
-    product_id = proto.Field(proto.STRING, number=3)
+    product_id = proto.Field(proto.STRING, number=3,)
 
 
 class ListProductsRequest(proto.Message):
@@ -252,18 +237,16 @@ class ListProductsRequest(proto.Message):
             if any.
     """
 
-    parent = proto.Field(proto.STRING, number=1)
-
-    page_size = proto.Field(proto.INT32, number=2)
-
-    page_token = proto.Field(proto.STRING, number=3)
+    parent = proto.Field(proto.STRING, number=1,)
+    page_size = proto.Field(proto.INT32, number=2,)
+    page_token = proto.Field(proto.STRING, number=3,)
 
 
 class ListProductsResponse(proto.Message):
     r"""Response message for the ``ListProducts`` method.
 
     Attributes:
-        products (Sequence[~.product_search_service.Product]):
+        products (Sequence[google.cloud.vision_v1p3beta1.types.Product]):
             List of products.
         next_page_token (str):
             Token to retrieve the next page of results,
@@ -276,8 +259,7 @@ class ListProductsResponse(proto.Message):
         return self
 
     products = proto.RepeatedField(proto.MESSAGE, number=1, message="Product",)
-
-    next_page_token = proto.Field(proto.STRING, number=2)
+    next_page_token = proto.Field(proto.STRING, number=2,)
 
 
 class GetProductRequest(proto.Message):
@@ -291,18 +273,18 @@ class GetProductRequest(proto.Message):
             ``projects/PROJECT_ID/locations/LOC_ID/products/PRODUCT_ID``
     """
 
-    name = proto.Field(proto.STRING, number=1)
+    name = proto.Field(proto.STRING, number=1,)
 
 
 class UpdateProductRequest(proto.Message):
     r"""Request message for the ``UpdateProduct`` method.
 
     Attributes:
-        product (~.product_search_service.Product):
+        product (google.cloud.vision_v1p3beta1.types.Product):
             Required. The Product resource which replaces
             the one on the server. product.name is
             immutable.
-        update_mask (~.field_mask.FieldMask):
+        update_mask (google.protobuf.field_mask_pb2.FieldMask):
             The [FieldMask][google.protobuf.FieldMask] that specifies
             which fields to update. If update_mask isn't specified, all
             mutable fields are to be updated. Valid mask paths include
@@ -310,8 +292,9 @@ class UpdateProductRequest(proto.Message):
     """
 
     product = proto.Field(proto.MESSAGE, number=1, message="Product",)
-
-    update_mask = proto.Field(proto.MESSAGE, number=2, message=field_mask.FieldMask,)
+    update_mask = proto.Field(
+        proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,
+    )
 
 
 class DeleteProductRequest(proto.Message):
@@ -325,7 +308,7 @@ class DeleteProductRequest(proto.Message):
             ``projects/PROJECT_ID/locations/LOC_ID/products/PRODUCT_ID``
     """
 
-    name = proto.Field(proto.STRING, number=1)
+    name = proto.Field(proto.STRING, number=1,)
 
 
 class CreateProductSetRequest(proto.Message):
@@ -337,7 +320,7 @@ class CreateProductSetRequest(proto.Message):
             created.
 
             Format is ``projects/PROJECT_ID/locations/LOC_ID``.
-        product_set (~.product_search_service.ProductSet):
+        product_set (google.cloud.vision_v1p3beta1.types.ProductSet):
             Required. The ProductSet to create.
         product_set_id (str):
             A user-supplied resource id for this ProductSet. If set, the
@@ -347,11 +330,9 @@ class CreateProductSetRequest(proto.Message):
             cannot contain the character ``/``.
     """
 
-    parent = proto.Field(proto.STRING, number=1)
-
+    parent = proto.Field(proto.STRING, number=1,)
     product_set = proto.Field(proto.MESSAGE, number=2, message="ProductSet",)
-
-    product_set_id = proto.Field(proto.STRING, number=3)
+    product_set_id = proto.Field(proto.STRING, number=3,)
 
 
 class ListProductSetsRequest(proto.Message):
@@ -371,18 +352,16 @@ class ListProductSetsRequest(proto.Message):
             if any.
     """
 
-    parent = proto.Field(proto.STRING, number=1)
-
-    page_size = proto.Field(proto.INT32, number=2)
-
-    page_token = proto.Field(proto.STRING, number=3)
+    parent = proto.Field(proto.STRING, number=1,)
+    page_size = proto.Field(proto.INT32, number=2,)
+    page_token = proto.Field(proto.STRING, number=3,)
 
 
 class ListProductSetsResponse(proto.Message):
     r"""Response message for the ``ListProductSets`` method.
 
     Attributes:
-        product_sets (Sequence[~.product_search_service.ProductSet]):
+        product_sets (Sequence[google.cloud.vision_v1p3beta1.types.ProductSet]):
             List of ProductSets.
         next_page_token (str):
             Token to retrieve the next page of results,
@@ -395,8 +374,7 @@ class ListProductSetsResponse(proto.Message):
         return self
 
     product_sets = proto.RepeatedField(proto.MESSAGE, number=1, message="ProductSet",)
-
-    next_page_token = proto.Field(proto.STRING, number=2)
+    next_page_token = proto.Field(proto.STRING, number=2,)
 
 
 class GetProductSetRequest(proto.Message):
@@ -410,17 +388,17 @@ class GetProductSetRequest(proto.Message):
             ``projects/PROJECT_ID/locations/LOC_ID/productSets/PRODUCT_SET_ID``
     """
 
-    name = proto.Field(proto.STRING, number=1)
+    name = proto.Field(proto.STRING, number=1,)
 
 
 class UpdateProductSetRequest(proto.Message):
     r"""Request message for the ``UpdateProductSet`` method.
 
     Attributes:
-        product_set (~.product_search_service.ProductSet):
+        product_set (google.cloud.vision_v1p3beta1.types.ProductSet):
             Required. The ProductSet resource which
             replaces the one on the server.
-        update_mask (~.field_mask.FieldMask):
+        update_mask (google.protobuf.field_mask_pb2.FieldMask):
             The [FieldMask][google.protobuf.FieldMask] that specifies
             which fields to update. If update_mask isn't specified, all
             mutable fields are to be updated. Valid mask path is
@@ -428,8 +406,9 @@ class UpdateProductSetRequest(proto.Message):
     """
 
     product_set = proto.Field(proto.MESSAGE, number=1, message="ProductSet",)
-
-    update_mask = proto.Field(proto.MESSAGE, number=2, message=field_mask.FieldMask,)
+    update_mask = proto.Field(
+        proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,
+    )
 
 
 class DeleteProductSetRequest(proto.Message):
@@ -443,7 +422,7 @@ class DeleteProductSetRequest(proto.Message):
             ``projects/PROJECT_ID/locations/LOC_ID/productSets/PRODUCT_SET_ID``
     """
 
-    name = proto.Field(proto.STRING, number=1)
+    name = proto.Field(proto.STRING, number=1,)
 
 
 class CreateReferenceImageRequest(proto.Message):
@@ -456,7 +435,7 @@ class CreateReferenceImageRequest(proto.Message):
 
             Format is
             ``projects/PROJECT_ID/locations/LOC_ID/products/PRODUCT_ID``.
-        reference_image (~.product_search_service.ReferenceImage):
+        reference_image (google.cloud.vision_v1p3beta1.types.ReferenceImage):
             Required. The reference image to create.
             If an image ID is specified, it is ignored.
         reference_image_id (str):
@@ -467,11 +446,9 @@ class CreateReferenceImageRequest(proto.Message):
             characters long. It cannot contain the character ``/``.
     """
 
-    parent = proto.Field(proto.STRING, number=1)
-
+    parent = proto.Field(proto.STRING, number=1,)
     reference_image = proto.Field(proto.MESSAGE, number=2, message="ReferenceImage",)
-
-    reference_image_id = proto.Field(proto.STRING, number=3)
+    reference_image_id = proto.Field(proto.STRING, number=3,)
 
 
 class ListReferenceImagesRequest(proto.Message):
@@ -495,18 +472,16 @@ class ListReferenceImagesRequest(proto.Message):
             Defaults to the first page if not specified.
     """
 
-    parent = proto.Field(proto.STRING, number=1)
-
-    page_size = proto.Field(proto.INT32, number=2)
-
-    page_token = proto.Field(proto.STRING, number=3)
+    parent = proto.Field(proto.STRING, number=1,)
+    page_size = proto.Field(proto.INT32, number=2,)
+    page_token = proto.Field(proto.STRING, number=3,)
 
 
 class ListReferenceImagesResponse(proto.Message):
     r"""Response message for the ``ListReferenceImages`` method.
 
     Attributes:
-        reference_images (Sequence[~.product_search_service.ReferenceImage]):
+        reference_images (Sequence[google.cloud.vision_v1p3beta1.types.ReferenceImage]):
             The list of reference images.
         page_size (int):
             The maximum number of items to return.
@@ -523,10 +498,8 @@ class ListReferenceImagesResponse(proto.Message):
     reference_images = proto.RepeatedField(
         proto.MESSAGE, number=1, message="ReferenceImage",
     )
-
-    page_size = proto.Field(proto.INT32, number=2)
-
-    next_page_token = proto.Field(proto.STRING, number=3)
+    page_size = proto.Field(proto.INT32, number=2,)
+    next_page_token = proto.Field(proto.STRING, number=3,)
 
 
 class GetReferenceImageRequest(proto.Message):
@@ -541,7 +514,7 @@ class GetReferenceImageRequest(proto.Message):
             ``projects/PROJECT_ID/locations/LOC_ID/products/PRODUCT_ID/referenceImages/IMAGE_ID``.
     """
 
-    name = proto.Field(proto.STRING, number=1)
+    name = proto.Field(proto.STRING, number=1,)
 
 
 class DeleteReferenceImageRequest(proto.Message):
@@ -557,7 +530,7 @@ class DeleteReferenceImageRequest(proto.Message):
             ``projects/PROJECT_ID/locations/LOC_ID/products/PRODUCT_ID/referenceImages/IMAGE_ID``
     """
 
-    name = proto.Field(proto.STRING, number=1)
+    name = proto.Field(proto.STRING, number=1,)
 
 
 class AddProductToProductSetRequest(proto.Message):
@@ -577,9 +550,8 @@ class AddProductToProductSetRequest(proto.Message):
             ``projects/PROJECT_ID/locations/LOC_ID/products/PRODUCT_ID``
     """
 
-    name = proto.Field(proto.STRING, number=1)
-
-    product = proto.Field(proto.STRING, number=2)
+    name = proto.Field(proto.STRING, number=1,)
+    product = proto.Field(proto.STRING, number=2,)
 
 
 class RemoveProductFromProductSetRequest(proto.Message):
@@ -599,9 +571,8 @@ class RemoveProductFromProductSetRequest(proto.Message):
             ``projects/PROJECT_ID/locations/LOC_ID/products/PRODUCT_ID``
     """
 
-    name = proto.Field(proto.STRING, number=1)
-
-    product = proto.Field(proto.STRING, number=2)
+    name = proto.Field(proto.STRING, number=1,)
+    product = proto.Field(proto.STRING, number=2,)
 
 
 class ListProductsInProductSetRequest(proto.Message):
@@ -622,18 +593,16 @@ class ListProductsInProductSetRequest(proto.Message):
             if any.
     """
 
-    name = proto.Field(proto.STRING, number=1)
-
-    page_size = proto.Field(proto.INT32, number=2)
-
-    page_token = proto.Field(proto.STRING, number=3)
+    name = proto.Field(proto.STRING, number=1,)
+    page_size = proto.Field(proto.INT32, number=2,)
+    page_token = proto.Field(proto.STRING, number=3,)
 
 
 class ListProductsInProductSetResponse(proto.Message):
     r"""Response message for the ``ListProductsInProductSet`` method.
 
     Attributes:
-        products (Sequence[~.product_search_service.Product]):
+        products (Sequence[google.cloud.vision_v1p3beta1.types.Product]):
             The list of Products.
         next_page_token (str):
             Token to retrieve the next page of results,
@@ -646,8 +615,7 @@ class ListProductsInProductSetResponse(proto.Message):
         return self
 
     products = proto.RepeatedField(proto.MESSAGE, number=1, message="Product",)
-
-    next_page_token = proto.Field(proto.STRING, number=2)
+    next_page_token = proto.Field(proto.STRING, number=2,)
 
 
 class ImportProductSetsGcsSource(proto.Message):
@@ -718,14 +686,14 @@ class ImportProductSetsGcsSource(proto.Message):
             polygons.
     """
 
-    csv_file_uri = proto.Field(proto.STRING, number=1)
+    csv_file_uri = proto.Field(proto.STRING, number=1,)
 
 
 class ImportProductSetsInputConfig(proto.Message):
     r"""The input content for the ``ImportProductSets`` method.
 
     Attributes:
-        gcs_source (~.product_search_service.ImportProductSetsGcsSource):
+        gcs_source (google.cloud.vision_v1p3beta1.types.ImportProductSetsGcsSource):
             The Google Cloud Storage location for a csv
             file which preserves a list of
             ImportProductSetRequests in each line.
@@ -745,13 +713,12 @@ class ImportProductSetsRequest(proto.Message):
             imported.
 
             Format is ``projects/PROJECT_ID/locations/LOC_ID``.
-        input_config (~.product_search_service.ImportProductSetsInputConfig):
+        input_config (google.cloud.vision_v1p3beta1.types.ImportProductSetsInputConfig):
             Required. The input content for the list of
             requests.
     """
 
-    parent = proto.Field(proto.STRING, number=1)
-
+    parent = proto.Field(proto.STRING, number=1,)
     input_config = proto.Field(
         proto.MESSAGE, number=2, message="ImportProductSetsInputConfig",
     )
@@ -767,9 +734,9 @@ class ImportProductSetsResponse(proto.Message):
     field.
 
     Attributes:
-        reference_images (Sequence[~.product_search_service.ReferenceImage]):
+        reference_images (Sequence[google.cloud.vision_v1p3beta1.types.ReferenceImage]):
             The list of reference_images that are imported successfully.
-        statuses (Sequence[~.status.Status]):
+        statuses (Sequence[google.rpc.status_pb2.Status]):
             The rpc status for each ImportProductSet request, including
             both successes and errors.
 
@@ -782,8 +749,7 @@ class ImportProductSetsResponse(proto.Message):
     reference_images = proto.RepeatedField(
         proto.MESSAGE, number=1, message="ReferenceImage",
     )
-
-    statuses = proto.RepeatedField(proto.MESSAGE, number=2, message=status.Status,)
+    statuses = proto.RepeatedField(proto.MESSAGE, number=2, message=status_pb2.Status,)
 
 
 class BatchOperationMetadata(proto.Message):
@@ -794,12 +760,12 @@ class BatchOperationMetadata(proto.Message):
     ``google::longrunning::Operations`` service.
 
     Attributes:
-        state (~.product_search_service.BatchOperationMetadata.State):
+        state (google.cloud.vision_v1p3beta1.types.BatchOperationMetadata.State):
             The current state of the batch operation.
-        submit_time (~.timestamp.Timestamp):
+        submit_time (google.protobuf.timestamp_pb2.Timestamp):
             The time when the batch request was submitted
             to the server.
-        end_time (~.timestamp.Timestamp):
+        end_time (google.protobuf.timestamp_pb2.Timestamp):
             The time when the batch request is finished and
             [google.longrunning.Operation.done][google.longrunning.Operation.done]
             is set to true.
@@ -816,10 +782,8 @@ class BatchOperationMetadata(proto.Message):
         CANCELLED = 4
 
     state = proto.Field(proto.ENUM, number=1, enum=State,)
-
-    submit_time = proto.Field(proto.MESSAGE, number=2, message=timestamp.Timestamp,)
-
-    end_time = proto.Field(proto.MESSAGE, number=3, message=timestamp.Timestamp,)
+    submit_time = proto.Field(proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,)
+    end_time = proto.Field(proto.MESSAGE, number=3, message=timestamp_pb2.Timestamp,)
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
