@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,22 +13,23 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import abc
-import typing
+from typing import Awaitable, Callable, Dict, Optional, Sequence, Union
+import packaging.version
 import pkg_resources
 
-from google import auth  # type: ignore
-from google.api_core import exceptions  # type: ignore
+import google.auth  # type: ignore
+import google.api_core  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
 from google.api_core import operations_v1  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
+from google.oauth2 import service_account  # type: ignore
 
 from google.cloud.vision_v1p4beta1.types import product_search_service
-from google.longrunning import operations_pb2 as operations  # type: ignore
-from google.protobuf import empty_pb2 as empty  # type: ignore
-
+from google.longrunning import operations_pb2  # type: ignore
+from google.protobuf import empty_pb2  # type: ignore
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
@@ -38,6 +38,15 @@ try:
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
 
+try:
+    # google.auth.__version__ was added in 1.26.0
+    _GOOGLE_AUTH_VERSION = google.auth.__version__
+except AttributeError:
+    try:  # try pkg_resources if it is available
+        _GOOGLE_AUTH_VERSION = pkg_resources.get_distribution("google-auth").version
+    except pkg_resources.DistributionNotFound:  # pragma: NO COVER
+        _GOOGLE_AUTH_VERSION = None
+
 
 class ProductSearchTransport(abc.ABC):
     """Abstract transport class for ProductSearch."""
@@ -47,21 +56,25 @@ class ProductSearchTransport(abc.ABC):
         "https://www.googleapis.com/auth/cloud-vision",
     )
 
+    DEFAULT_HOST: str = "vision.googleapis.com"
+
     def __init__(
         self,
         *,
-        host: str = "vision.googleapis.com",
-        credentials: credentials.Credentials = None,
-        credentials_file: typing.Optional[str] = None,
-        scopes: typing.Optional[typing.Sequence[str]] = AUTH_SCOPES,
-        quota_project_id: typing.Optional[str] = None,
+        host: str = DEFAULT_HOST,
+        credentials: ga_credentials.Credentials = None,
+        credentials_file: Optional[str] = None,
+        scopes: Optional[Sequence[str]] = None,
+        quota_project_id: Optional[str] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
+        always_use_jwt_access: Optional[bool] = False,
         **kwargs,
     ) -> None:
         """Instantiate the transport.
 
         Args:
-            host (Optional[str]): The hostname to connect to.
+            host (Optional[str]):
+                 The hostname to connect to.
             credentials (Optional[google.auth.credentials.Credentials]): The
                 authorization credentials to attach to requests. These
                 credentials identify the application to the service; if none
@@ -70,42 +83,77 @@ class ProductSearchTransport(abc.ABC):
             credentials_file (Optional[str]): A file with credentials that can
                 be loaded with :func:`google.auth.load_credentials_from_file`.
                 This argument is mutually exclusive with credentials.
-            scope (Optional[Sequence[str]]): A list of scopes.
+            scopes (Optional[Sequence[str]]): A list of scopes.
             quota_project_id (Optional[str]): An optional project to use for billing
                 and quota.
-            client_info (google.api_core.gapic_v1.client_info.ClientInfo):	
-                The client info used to send a user-agent string along with	
-                API requests. If ``None``, then default info will be used.	
-                Generally, you only need to set this if you're developing	
+            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
+                The client info used to send a user-agent string along with
+                API requests. If ``None``, then default info will be used.
+                Generally, you only need to set this if you're developing
                 your own client library.
+            always_use_jwt_access (Optional[bool]): Whether self signed JWT should
+                be used for service account credentials.
         """
         # Save the hostname. Default to port 443 (HTTPS) if none is specified.
         if ":" not in host:
             host += ":443"
         self._host = host
 
+        scopes_kwargs = self._get_scopes_kwargs(self._host, scopes)
+
+        # Save the scopes.
+        self._scopes = scopes
+
         # If no credentials are provided, then determine the appropriate
         # defaults.
         if credentials and credentials_file:
-            raise exceptions.DuplicateCredentialArgs(
+            raise core_exceptions.DuplicateCredentialArgs(
                 "'credentials_file' and 'credentials' are mutually exclusive"
             )
 
         if credentials_file is not None:
-            credentials, _ = auth.load_credentials_from_file(
-                credentials_file, scopes=scopes, quota_project_id=quota_project_id
+            credentials, _ = google.auth.load_credentials_from_file(
+                credentials_file, **scopes_kwargs, quota_project_id=quota_project_id
             )
 
         elif credentials is None:
-            credentials, _ = auth.default(
-                scopes=scopes, quota_project_id=quota_project_id
+            credentials, _ = google.auth.default(
+                **scopes_kwargs, quota_project_id=quota_project_id
             )
 
+        # If the credentials are service account credentials, then always try to use self signed JWT.
+        if (
+            always_use_jwt_access
+            and isinstance(credentials, service_account.Credentials)
+            and hasattr(service_account.Credentials, "with_always_use_jwt_access")
+        ):
+            credentials = credentials.with_always_use_jwt_access(True)
+
         # Save the credentials.
         self._credentials = credentials
 
-        # Lifted into its own function so it can be stubbed out during tests.
-        self._prep_wrapped_messages(client_info)
+    # TODO(busunkim): This method is in the base transport
+    # to avoid duplicating code across the transport classes. These functions
+    # should be deleted once the minimum required versions of google-auth is increased.
+
+    # TODO: Remove this function once google-auth >= 1.25.0 is required
+    @classmethod
+    def _get_scopes_kwargs(
+        cls, host: str, scopes: Optional[Sequence[str]]
+    ) -> Dict[str, Optional[Sequence[str]]]:
+        """Returns scopes kwargs to pass to google-auth methods depending on the google-auth version"""
+
+        scopes_kwargs = {}
+
+        if _GOOGLE_AUTH_VERSION and (
+            packaging.version.parse(_GOOGLE_AUTH_VERSION)
+            >= packaging.version.parse("1.25.0")
+        ):
+            scopes_kwargs = {"scopes": scopes, "default_scopes": cls.AUTH_SCOPES}
+        else:
+            scopes_kwargs = {"scopes": scopes or cls.AUTH_SCOPES}
+
+        return scopes_kwargs
 
     def _prep_wrapped_messages(self, client_info):
         # Precompute the wrapped methods.
@@ -117,6 +165,7 @@ class ProductSearchTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(),
+                    deadline=600.0,
                 ),
                 default_timeout=600.0,
                 client_info=client_info,
@@ -128,8 +177,10 @@ class ProductSearchTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(
-                        exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                        core_exceptions.DeadlineExceeded,
+                        core_exceptions.ServiceUnavailable,
                     ),
+                    deadline=600.0,
                 ),
                 default_timeout=600.0,
                 client_info=client_info,
@@ -141,8 +192,10 @@ class ProductSearchTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(
-                        exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                        core_exceptions.DeadlineExceeded,
+                        core_exceptions.ServiceUnavailable,
                     ),
+                    deadline=600.0,
                 ),
                 default_timeout=600.0,
                 client_info=client_info,
@@ -154,6 +207,7 @@ class ProductSearchTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(),
+                    deadline=600.0,
                 ),
                 default_timeout=600.0,
                 client_info=client_info,
@@ -165,8 +219,10 @@ class ProductSearchTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(
-                        exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                        core_exceptions.DeadlineExceeded,
+                        core_exceptions.ServiceUnavailable,
                     ),
+                    deadline=600.0,
                 ),
                 default_timeout=600.0,
                 client_info=client_info,
@@ -178,6 +234,7 @@ class ProductSearchTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(),
+                    deadline=600.0,
                 ),
                 default_timeout=600.0,
                 client_info=client_info,
@@ -189,8 +246,10 @@ class ProductSearchTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(
-                        exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                        core_exceptions.DeadlineExceeded,
+                        core_exceptions.ServiceUnavailable,
                     ),
+                    deadline=600.0,
                 ),
                 default_timeout=600.0,
                 client_info=client_info,
@@ -202,8 +261,10 @@ class ProductSearchTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(
-                        exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                        core_exceptions.DeadlineExceeded,
+                        core_exceptions.ServiceUnavailable,
                     ),
+                    deadline=600.0,
                 ),
                 default_timeout=600.0,
                 client_info=client_info,
@@ -215,6 +276,7 @@ class ProductSearchTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(),
+                    deadline=600.0,
                 ),
                 default_timeout=600.0,
                 client_info=client_info,
@@ -226,8 +288,10 @@ class ProductSearchTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(
-                        exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                        core_exceptions.DeadlineExceeded,
+                        core_exceptions.ServiceUnavailable,
                     ),
+                    deadline=600.0,
                 ),
                 default_timeout=600.0,
                 client_info=client_info,
@@ -239,6 +303,7 @@ class ProductSearchTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(),
+                    deadline=600.0,
                 ),
                 default_timeout=600.0,
                 client_info=client_info,
@@ -250,8 +315,10 @@ class ProductSearchTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(
-                        exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                        core_exceptions.DeadlineExceeded,
+                        core_exceptions.ServiceUnavailable,
                     ),
+                    deadline=600.0,
                 ),
                 default_timeout=600.0,
                 client_info=client_info,
@@ -263,8 +330,10 @@ class ProductSearchTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(
-                        exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                        core_exceptions.DeadlineExceeded,
+                        core_exceptions.ServiceUnavailable,
                     ),
+                    deadline=600.0,
                 ),
                 default_timeout=600.0,
                 client_info=client_info,
@@ -276,8 +345,10 @@ class ProductSearchTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(
-                        exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                        core_exceptions.DeadlineExceeded,
+                        core_exceptions.ServiceUnavailable,
                     ),
+                    deadline=600.0,
                 ),
                 default_timeout=600.0,
                 client_info=client_info,
@@ -289,6 +360,7 @@ class ProductSearchTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(),
+                    deadline=600.0,
                 ),
                 default_timeout=600.0,
                 client_info=client_info,
@@ -300,6 +372,7 @@ class ProductSearchTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(),
+                    deadline=600.0,
                 ),
                 default_timeout=600.0,
                 client_info=client_info,
@@ -311,8 +384,10 @@ class ProductSearchTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(
-                        exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                        core_exceptions.DeadlineExceeded,
+                        core_exceptions.ServiceUnavailable,
                     ),
+                    deadline=600.0,
                 ),
                 default_timeout=600.0,
                 client_info=client_info,
@@ -324,6 +399,7 @@ class ProductSearchTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(),
+                    deadline=600.0,
                 ),
                 default_timeout=600.0,
                 client_info=client_info,
@@ -333,6 +409,15 @@ class ProductSearchTransport(abc.ABC):
             ),
         }
 
+    def close(self):
+        """Closes resources associated with the transport.
+
+       .. warning::
+            Only call this method if the transport is NOT shared
+            with other clients - this may cause errors in other clients!
+        """
+        raise NotImplementedError()
+
     @property
     def operations_client(self) -> operations_v1.OperationsClient:
         """Return the client designed to process long-running operations."""
@@ -341,11 +426,11 @@ class ProductSearchTransport(abc.ABC):
     @property
     def create_product_set(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [product_search_service.CreateProductSetRequest],
-        typing.Union[
+        Union[
             product_search_service.ProductSet,
-            typing.Awaitable[product_search_service.ProductSet],
+            Awaitable[product_search_service.ProductSet],
         ],
     ]:
         raise NotImplementedError()
@@ -353,11 +438,11 @@ class ProductSearchTransport(abc.ABC):
     @property
     def list_product_sets(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [product_search_service.ListProductSetsRequest],
-        typing.Union[
+        Union[
             product_search_service.ListProductSetsResponse,
-            typing.Awaitable[product_search_service.ListProductSetsResponse],
+            Awaitable[product_search_service.ListProductSetsResponse],
         ],
     ]:
         raise NotImplementedError()
@@ -365,11 +450,11 @@ class ProductSearchTransport(abc.ABC):
     @property
     def get_product_set(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [product_search_service.GetProductSetRequest],
-        typing.Union[
+        Union[
             product_search_service.ProductSet,
-            typing.Awaitable[product_search_service.ProductSet],
+            Awaitable[product_search_service.ProductSet],
         ],
     ]:
         raise NotImplementedError()
@@ -377,11 +462,11 @@ class ProductSearchTransport(abc.ABC):
     @property
     def update_product_set(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [product_search_service.UpdateProductSetRequest],
-        typing.Union[
+        Union[
             product_search_service.ProductSet,
-            typing.Awaitable[product_search_service.ProductSet],
+            Awaitable[product_search_service.ProductSet],
         ],
     ]:
         raise NotImplementedError()
@@ -389,20 +474,19 @@ class ProductSearchTransport(abc.ABC):
     @property
     def delete_product_set(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [product_search_service.DeleteProductSetRequest],
-        typing.Union[empty.Empty, typing.Awaitable[empty.Empty]],
+        Union[empty_pb2.Empty, Awaitable[empty_pb2.Empty]],
     ]:
         raise NotImplementedError()
 
     @property
     def create_product(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [product_search_service.CreateProductRequest],
-        typing.Union[
-            product_search_service.Product,
-            typing.Awaitable[product_search_service.Product],
+        Union[
+            product_search_service.Product, Awaitable[product_search_service.Product]
         ],
     ]:
         raise NotImplementedError()
@@ -410,11 +494,11 @@ class ProductSearchTransport(abc.ABC):
     @property
     def list_products(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [product_search_service.ListProductsRequest],
-        typing.Union[
+        Union[
             product_search_service.ListProductsResponse,
-            typing.Awaitable[product_search_service.ListProductsResponse],
+            Awaitable[product_search_service.ListProductsResponse],
         ],
     ]:
         raise NotImplementedError()
@@ -422,11 +506,10 @@ class ProductSearchTransport(abc.ABC):
     @property
     def get_product(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [product_search_service.GetProductRequest],
-        typing.Union[
-            product_search_service.Product,
-            typing.Awaitable[product_search_service.Product],
+        Union[
+            product_search_service.Product, Awaitable[product_search_service.Product]
         ],
     ]:
         raise NotImplementedError()
@@ -434,11 +517,10 @@ class ProductSearchTransport(abc.ABC):
     @property
     def update_product(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [product_search_service.UpdateProductRequest],
-        typing.Union[
-            product_search_service.Product,
-            typing.Awaitable[product_search_service.Product],
+        Union[
+            product_search_service.Product, Awaitable[product_search_service.Product]
         ],
     ]:
         raise NotImplementedError()
@@ -446,20 +528,20 @@ class ProductSearchTransport(abc.ABC):
     @property
     def delete_product(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [product_search_service.DeleteProductRequest],
-        typing.Union[empty.Empty, typing.Awaitable[empty.Empty]],
+        Union[empty_pb2.Empty, Awaitable[empty_pb2.Empty]],
     ]:
         raise NotImplementedError()
 
     @property
     def create_reference_image(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [product_search_service.CreateReferenceImageRequest],
-        typing.Union[
+        Union[
             product_search_service.ReferenceImage,
-            typing.Awaitable[product_search_service.ReferenceImage],
+            Awaitable[product_search_service.ReferenceImage],
         ],
     ]:
         raise NotImplementedError()
@@ -467,20 +549,20 @@ class ProductSearchTransport(abc.ABC):
     @property
     def delete_reference_image(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [product_search_service.DeleteReferenceImageRequest],
-        typing.Union[empty.Empty, typing.Awaitable[empty.Empty]],
+        Union[empty_pb2.Empty, Awaitable[empty_pb2.Empty]],
     ]:
         raise NotImplementedError()
 
     @property
     def list_reference_images(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [product_search_service.ListReferenceImagesRequest],
-        typing.Union[
+        Union[
             product_search_service.ListReferenceImagesResponse,
-            typing.Awaitable[product_search_service.ListReferenceImagesResponse],
+            Awaitable[product_search_service.ListReferenceImagesResponse],
         ],
     ]:
         raise NotImplementedError()
@@ -488,11 +570,11 @@ class ProductSearchTransport(abc.ABC):
     @property
     def get_reference_image(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [product_search_service.GetReferenceImageRequest],
-        typing.Union[
+        Union[
             product_search_service.ReferenceImage,
-            typing.Awaitable[product_search_service.ReferenceImage],
+            Awaitable[product_search_service.ReferenceImage],
         ],
     ]:
         raise NotImplementedError()
@@ -500,29 +582,29 @@ class ProductSearchTransport(abc.ABC):
     @property
     def add_product_to_product_set(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [product_search_service.AddProductToProductSetRequest],
-        typing.Union[empty.Empty, typing.Awaitable[empty.Empty]],
+        Union[empty_pb2.Empty, Awaitable[empty_pb2.Empty]],
     ]:
         raise NotImplementedError()
 
     @property
     def remove_product_from_product_set(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [product_search_service.RemoveProductFromProductSetRequest],
-        typing.Union[empty.Empty, typing.Awaitable[empty.Empty]],
+        Union[empty_pb2.Empty, Awaitable[empty_pb2.Empty]],
     ]:
         raise NotImplementedError()
 
     @property
     def list_products_in_product_set(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [product_search_service.ListProductsInProductSetRequest],
-        typing.Union[
+        Union[
             product_search_service.ListProductsInProductSetResponse,
-            typing.Awaitable[product_search_service.ListProductsInProductSetResponse],
+            Awaitable[product_search_service.ListProductsInProductSetResponse],
         ],
     ]:
         raise NotImplementedError()
@@ -530,18 +612,18 @@ class ProductSearchTransport(abc.ABC):
     @property
     def import_product_sets(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [product_search_service.ImportProductSetsRequest],
-        typing.Union[operations.Operation, typing.Awaitable[operations.Operation]],
+        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
     ]:
         raise NotImplementedError()
 
     @property
     def purge_products(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [product_search_service.PurgeProductsRequest],
-        typing.Union[operations.Operation, typing.Awaitable[operations.Operation]],
+        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
     ]:
         raise NotImplementedError()
 
